distlib: Distribution utilities
===============================

Description
-----------

Distribution utilities

License
-------

Python license

Upstream Contact
----------------

https://pypi.org/project/distlib/

